PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/sbt.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

sbt.h
Go to the documentation of this file.
1
9 #ifndef SBT_H
10 #define SBT_H
11
12 #include <complex.h>
13
17 typedef struct sbt_descriptor {
18 double kmin;
19 double kappamin;
20 double rmin;
21 double rhomin;
22 double drho;
23 double dt;
24 int N;
25 double complex** mult_table;
26 double* ks;
27 double* rs;
28 int lmax;
29 } sbt_descriptor_t;
30
39 sbt_descriptor_t* spherical_bessel_transform_setup(double encut, double enbuf, int lmax, int N,
40 double* r, double* ks);
41
48 double* wave_spherical_bessel_transform(sbt_descriptor_t* d, double* f, int l);
49
56 double* inverse_wave_spherical_bessel_transform(sbt_descriptor_t* d, double* f, int l);
57
61 void free_sbt_descriptor(sbt_descriptor_t* d);
62
63 #endif
sbt_descriptor::dt
double dt
increment of the multiplication table
Definition: sbt.h:23
free_sbt_descriptor
void free_sbt_descriptor(sbt_descriptor_t *d)
sbt_descriptor::N
int N
number of values of r and k
Definition: sbt.h:24
sbt_descriptor::drho
double drho
linear increment of rho = ln(r), drho == dkappa
Definition: sbt.h:22
pawpyseed.core.gaunt.f
f
Definition: gaunt.py:29
wave_spherical_bessel_transform
double * wave_spherical_bessel_transform(sbt_descriptor_t *d, double *f, int l)
sbt_descriptor::kappamin
double kappamin
ln(kmin)
Definition: sbt.h:19
spherical_bessel_transform_setup
sbt_descriptor_t * spherical_bessel_transform_setup(double encut, double enbuf, int lmax, int N, double *r, double *ks)
sbt_descriptor::rs
double * rs
Real space grid.
Definition: sbt.h:27
sbt_descriptor::kmin
double kmin
Minimum reciprocal space value.
Definition: sbt.h:18
sbt_descriptor
Definition: sbt.h:17
sbt_descriptor::rhomin
double rhomin
ln(rmin)
Definition: sbt.h:21
sbt_descriptor::mult_table
double complex ** mult_table
M_l(t) for l up to lmax.
Definition: sbt.h:25
sbt_descriptor::ks
double * ks
Reciprocal space grid.
Definition: sbt.h:26
sbt_descriptor::lmax
int lmax
Definition: sbt.h:28
inverse_wave_spherical_bessel_transform
double * inverse_wave_spherical_bessel_transform(sbt_descriptor_t *d, double *f, int l)
sbt_descriptor::rmin
double rmin
Minimum real space value.
Definition: sbt.h:20
pawpyseed.core.rayleigh.r
r
Definition: rayleigh.py:38
sbt_descriptor_t
struct sbt_descriptor sbt_descriptor_t